==> remmina-1%3A1.3.4-1-armv6h.pkg.tar.xz: usr/include/remmina/remmina_trace_calls.h <==
/*
 * Remmina - The GTK+ Remote Desktop Client
 * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
 * Copyright (C) 2016-2019 Antenore Gatta, Giovanni Panozzo
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 *
 *  In addition, as a special exception, the copyright holders give
 *  permission to link the code of portions of this program with the
 *  OpenSSL library under certain conditions as described in each
 *  individual source file, and distribute linked combinations
 *  including the two.
 *  You must obey the GNU General Public License in all respects
 *  for all of the code used other than OpenSSL. *  If you modify
 *  file(s) with this exception, you may extend this exception to your
 *  version of the file(s), but you are not obligated to do so. *  If you
 *  do not wish to do so, delete this exception statement from your
 *  version. *  If you delete this exception statement from all source
 *  files in the program, then also delete it here.
 *
 */

#pragma once

#ifdef  WITH_TRACE_CALLS

#include <gtk/gtk.h>

#define TRACE_CALL(text) \
	{ \
		GDateTime *datetime = g_date_time_new_now_local(); \
		gchar *sfmtdate = g_date_time_format(datetime, "%x %X"); \
		g_print("%s Trace calls: %s\n", sfmtdate, text); \
		g_free(sfmtdate); \
		g_date_time_unref(datetime); \
	}

#else
#define TRACE_CALL(text)
#endif  /* _WITH_TRACE_CALLS_ */

==> remmina-1%3A1.4.4-1-armv6h.pkg.tar.xz: usr/include/remmina/remmina_trace_calls.h <==
/*
 * Remmina - The GTK+ Remote Desktop Client
 * Copyright (C) 2014-2015 Antenore Gatta, Fabio Castelli, Giovanni Panozzo
 * Copyright (C) 2016-2020 Antenore Gatta, Giovanni Panozzo
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 *
 *  In addition, as a special exception, the copyright holders give
 *  permission to link the code of portions of this program with the
 *  OpenSSL library under certain conditions as described in each
 *  individual source file, and distribute linked combinations
 *  including the two.
 *  You must obey the GNU General Public License in all respects
 *  for all of the code used other than OpenSSL. *  If you modify
 *  file(s) with this exception, you may extend this exception to your
 *  version of the file(s), but you are not obligated to do so. *  If you
 *  do not wish to do so, delete this exception statement from your
 *  version. *  If you delete this exception statement from all source
 *  files in the program, then also delete it here.
 *
 */

#pragma once

#include <gtk/gtk.h>

extern char *fun; /* function name externalized to be used everywhere */
#define UNUSED(expr) do { (void)(expr); } while (0)

#ifdef  WITH_TRACE_CALLS
#define TRACE_CALL(text) \
	{ \
		fun = g_strdup (text); \
		UNUSED(fun); \
		GDateTime *datetime = g_date_time_new_now_local(); \
		gchar *sfmtdate = g_date_time_format(datetime, "%x %X"); \
		g_print("%s Trace calls: %s\n", sfmtdate, text); \
		g_free(sfmtdate); \
		g_date_time_unref(datetime); \
	}
#else
#define TRACE_CALL(text) \
	{ \
		fun = g_strdup (text); \
		UNUSED(fun); \
	}
#endif  /* _WITH_TRACE_CALLS_ */
